<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl" sourcelanguage="en">
<context>
    <name>AppChooserDialog</name>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="14"/>
        <source>Choose an Application</source>
        <translation>Kies een toepassing</translation>
    </message>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="36"/>
        <source>Installed Applications</source>
        <translation>Geïnstalleerde toepassingen</translation>
    </message>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="46"/>
        <source>Custom Command</source>
        <translation>Aangepaste opdracht</translation>
    </message>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="52"/>
        <source>Command line to execute:</source>
        <translation>Uit te voeren opdracht:</translation>
    </message>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="62"/>
        <source>Application name:</source>
        <translation>Naam van toepassing:</translation>
    </message>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="72"/>
        <source>&lt;b&gt;These special codes can be used in the command line:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: Represents a single file name&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: Represents multiple file names&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: Represents a single URI of the file&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: Represents multiple URIs&lt;/li&gt;
&lt;/ul&gt;</source>
        <translation>&lt;b&gt;Deze speciale codes kunt u gebruiken in de opdrachtregel:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: Vertegenwoordigt een enkele bestandnaam&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: Vertegenwoordigt meerdere bestandnamen&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: Vertegenwoordigt een enkele URI van het bestand&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: Vertegenwoordigt meerdere URI&apos;s&lt;/li&gt;
&lt;/ul&gt;</translation>
    </message>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="91"/>
        <source>Keep terminal window open after command execution</source>
        <translation>Houd terminalvenster open na het uitvoeren van opdracht</translation>
    </message>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="98"/>
        <source>Execute in terminal emulator</source>
        <translation>Voer uit in een terminalnabootser</translation>
    </message>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="109"/>
        <source>Set selected application as default action of this file type</source>
        <translation>Stel gekozen toepassing in als standaardactie voor deze bestandsoort</translation>
    </message>
</context>
<context>
    <name>EditBookmarksDialog</name>
    <message>
        <location filename="../../edit-bookmarks.ui" line="14"/>
        <source>Edit Bookmarks</source>
        <translation>Bladwijzers bewerken</translation>
    </message>
    <message>
        <location filename="../../edit-bookmarks.ui" line="42"/>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location filename="../../edit-bookmarks.ui" line="47"/>
        <source>Location</source>
        <translation>Plaats</translation>
    </message>
    <message>
        <location filename="../../edit-bookmarks.ui" line="67"/>
        <source>&amp;Add Item</source>
        <translation>Element &amp;toevoegen</translation>
    </message>
    <message>
        <location filename="../../edit-bookmarks.ui" line="77"/>
        <source>&amp;Remove Item</source>
        <translation>Element &amp;verwijderen</translation>
    </message>
    <message>
        <location filename="../../edit-bookmarks.ui" line="102"/>
        <source>Use drag and drop to reorder the items</source>
        <translation>Gebruik sleur en pleur om de elementen opnieuw te rangschikken</translation>
    </message>
</context>
<context>
    <name>ExecFileDialog</name>
    <message>
        <location filename="../../exec-file.ui" line="14"/>
        <source>Execute file</source>
        <translation>Bestand uitvoeren</translation>
    </message>
    <message>
        <location filename="../../exec-file.ui" line="39"/>
        <source>&amp;Open</source>
        <translation>O&amp;penen</translation>
    </message>
    <message>
        <location filename="../../exec-file.ui" line="52"/>
        <source>E&amp;xecute</source>
        <translation>&amp;Uitvoeren</translation>
    </message>
    <message>
        <location filename="../../exec-file.ui" line="62"/>
        <source>Execute in &amp;Terminal</source>
        <translation>In een &amp;terminal uitvoeren</translation>
    </message>
    <message>
        <location filename="../../exec-file.ui" line="85"/>
        <source>Cancel</source>
        <translation>Afbreken</translation>
    </message>
</context>
<context>
    <name>FileOperationDialog</name>
    <message>
        <location filename="../../file-operation-dialog.ui" line="32"/>
        <source>Destination:</source>
        <translation>Doel:</translation>
    </message>
    <message>
        <location filename="../../file-operation-dialog.ui" line="55"/>
        <source>Processing:</source>
        <translation>Bezig met:</translation>
    </message>
    <message>
        <location filename="../../file-operation-dialog.ui" line="68"/>
        <source>Preparing...</source>
        <translation>Voorbereiden...</translation>
    </message>
    <message>
        <location filename="../../file-operation-dialog.ui" line="75"/>
        <source>Progress</source>
        <translation>Voortgang</translation>
    </message>
    <message>
        <location filename="../../file-operation-dialog.ui" line="95"/>
        <source>Time remaining:</source>
        <translation>Resterende tijd:</translation>
    </message>
</context>
<context>
    <name>FilePropsDialog</name>
    <message>
        <location filename="../../file-props.ui" line="14"/>
        <source>File Properties</source>
        <translation>Bestandeigenschappen</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="41"/>
        <source>General</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="80"/>
        <source>Location:</source>
        <translation>Locatie:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="106"/>
        <source>File type:</source>
        <translation>Bestandsoort:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="129"/>
        <source>MIME type:</source>
        <translation>MIME-type:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="152"/>
        <source>File size:</source>
        <translation>Bestandgrootte:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="175"/>
        <source>On-disk size:</source>
        <translation>Omvang op schijf:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="198"/>
        <source>Last modified:</source>
        <translation>Laatst gewijzigd:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="221"/>
        <source>Link target:</source>
        <translation>Koppelingsdoel:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="247"/>
        <source>Open With:</source>
        <translation>Openen met:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="267"/>
        <source>Last accessed:</source>
        <translation>Laatst benaderd:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="285"/>
        <source>Permissions</source>
        <translation>Rechten</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="300"/>
        <source>Ownership</source>
        <translation>Eigendom</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="324"/>
        <location filename="../../file-props.ui" line="389"/>
        <location filename="../../file-props.ui" line="503"/>
        <source>Group:</source>
        <translation>Groep:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="337"/>
        <location filename="../../file-props.ui" line="372"/>
        <location filename="../../file-props.ui" line="451"/>
        <source>Owner:</source>
        <translation>Eigenaar:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="353"/>
        <source>Access Control</source>
        <translation>Toegangsbeheer</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="406"/>
        <location filename="../../file-props.ui" line="555"/>
        <source>Other:</source>
        <translation>Overige:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="423"/>
        <source>Make the file executable</source>
        <translation>Bestand uitvoerbaar maken</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="464"/>
        <location filename="../../file-props.ui" line="516"/>
        <location filename="../../file-props.ui" line="568"/>
        <source>Read</source>
        <translation>Lezen</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="477"/>
        <location filename="../../file-props.ui" line="529"/>
        <location filename="../../file-props.ui" line="581"/>
        <source>Write</source>
        <translation>Schrijven</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="490"/>
        <location filename="../../file-props.ui" line="542"/>
        <location filename="../../file-props.ui" line="594"/>
        <source>Execute</source>
        <translation>Uitvoeren</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="603"/>
        <source>Sticky</source>
        <translation>Sticky</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="610"/>
        <source>SetUID</source>
        <translation>SetUID</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="617"/>
        <source>SetGID</source>
        <translation>SetGID</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="653"/>
        <source>Advanced Mode</source>
        <translation>Geavanceerde modus</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserComboBox</name>
    <message>
        <location filename="../../appchoosercombobox.cpp" line="67"/>
        <source>Customize</source>
        <translation>Aanpassen</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserDialog</name>
    <message>
        <location filename="../../appchooserdialog.cpp" line="262"/>
        <source>Select an application to open &quot;%1&quot; files</source>
        <translation>Kies een toepassing voor het openen van &quot;%1&quot; bestanden</translation>
    </message>
</context>
<context>
    <name>Fm::CreateNewMenu</name>
    <message>
        <location filename="../../createnewmenu.cpp" line="30"/>
        <source>Folder</source>
        <translation>Map</translation>
    </message>
    <message>
        <location filename="../../createnewmenu.cpp" line="34"/>
        <source>Blank File</source>
        <translation>Leeg bestand</translation>
    </message>
</context>
<context>
    <name>Fm::DirListJob</name>
    <message>
        <location filename="../../core/dirlistjob.cpp" line="45"/>
        <source>The specified directory &apos;%1&apos; is not valid</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeModel</name>
    <message>
        <location filename="../../dirtreemodelitem.cpp" line="85"/>
        <source>Loading...</source>
        <translation>Laden...</translation>
    </message>
    <message>
        <location filename="../../dirtreemodelitem.cpp" line="268"/>
        <location filename="../../dirtreemodelitem.cpp" line="312"/>
        <location filename="../../dirtreemodelitem.cpp" line="410"/>
        <source>&lt;No sub folders&gt;</source>
        <translation>&lt;Geen submappen&gt;</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeView</name>
    <message>
        <location filename="../../dirtreeview.cpp" line="211"/>
        <source>Open in New T&amp;ab</source>
        <translation>Open in nieuw t&amp;abblad</translation>
    </message>
    <message>
        <location filename="../../dirtreeview.cpp" line="215"/>
        <source>Open in New Win&amp;dow</source>
        <translation>Open in nieuw &amp;venster</translation>
    </message>
    <message>
        <location filename="../../dirtreeview.cpp" line="220"/>
        <source>Open in Termina&amp;l</source>
        <translation>Open in termina&amp;lvenster</translation>
    </message>
</context>
<context>
    <name>Fm::DndActionMenu</name>
    <message>
        <location filename="../../dndactionmenu.cpp" line="32"/>
        <source>Copy here</source>
        <translation>Hierheen kopiëren</translation>
    </message>
    <message>
        <location filename="../../dndactionmenu.cpp" line="35"/>
        <source>Move here</source>
        <translation>Hierheen verplaatsen</translation>
    </message>
    <message>
        <location filename="../../dndactionmenu.cpp" line="38"/>
        <source>Create symlink here</source>
        <translation>Maak hier een symbolische koppeling</translation>
    </message>
    <message>
        <location filename="../../dndactionmenu.cpp" line="41"/>
        <source>Cancel</source>
        <translation>Afbreken</translation>
    </message>
</context>
<context>
    <name>Fm::EditBookmarksDialog</name>
    <message>
        <location filename="../../editbookmarksdialog.cpp" line="98"/>
        <source>New bookmark</source>
        <translation>Nieuwe bladwijzer</translation>
    </message>
</context>
<context>
    <name>Fm::ExecFileDialog</name>
    <message>
        <location filename="../../execfiledialog.cpp" line="40"/>
        <source>This text file &apos;%1&apos; seems to be an executable script.
What do you want to do with it?</source>
        <translation>Het tekstbestand &apos;%1&apos; lijkt een uitvoerbaar script te zijn.
Wat wilt u ermee doen?</translation>
    </message>
    <message>
        <location filename="../../execfiledialog.cpp" line="45"/>
        <source>This file &apos;%1&apos; is executable. Do you want to execute it?</source>
        <translation>Het bestand &apos;%1&apos; is uitvoerbaar. Wilt u het uitvoeren?</translation>
    </message>
</context>
<context>
    <name>Fm::FileMenu</name>
    <message>
        <location filename="../../filemenu.cpp" line="82"/>
        <source>Open</source>
        <translation>Openen</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="120"/>
        <source>Create &amp;New</source>
        <translation>&amp;Nieuw maken</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="139"/>
        <source>&amp;Restore</source>
        <translation>Te&amp;rugzetten</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="145"/>
        <source>Cut</source>
        <translation>Knippen</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="149"/>
        <source>Copy</source>
        <translation>Kopiëren</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="153"/>
        <source>Paste</source>
        <translation>Plakken</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="157"/>
        <location filename="../../filemenu.cpp" line="348"/>
        <source>&amp;Move to Trash</source>
        <translation>Naar de &amp;prullenbak verplaatsen</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="297"/>
        <source>Output</source>
        <translation>Uitvoer</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="348"/>
        <source>&amp;Delete</source>
        <translation>&amp;Wissen</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="161"/>
        <source>Rename</source>
        <translation>Hernoemen</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="86"/>
        <source>Open With...</source>
        <translation>Openen met...</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="114"/>
        <source>Other Applications</source>
        <translation>Andere toepassingen</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="188"/>
        <source>Extract to...</source>
        <translation>Uitpakken naar...</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="193"/>
        <source>Extract Here</source>
        <translation>Hier uitpakken</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="199"/>
        <source>Compress</source>
        <translation>Comprimeren</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="209"/>
        <source>Properties</source>
        <translation>Eigenschappen</translation>
    </message>
</context>
<context>
    <name>Fm::FileOperation</name>
    <message>
        <location filename="../../fileoperation.cpp" line="227"/>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <location filename="../../fileoperation.cpp" line="228"/>
        <source>Some files cannot be moved to trash can because the underlying file systems don&apos;t support this operation.
Do you want to delete them instead?</source>
        <translation>Sommige bestanden kunnen niet naar de prullenbak worden verplaatst, omdat de onderliggende bestandssystemen deze bewerking niet ondersteunen.
Wilt u ze in plaats daarvan blijvend verwijderen?</translation>
    </message>
    <message>
        <location filename="../../fileoperation.cpp" line="270"/>
        <location filename="../../fileoperation.cpp" line="287"/>
        <source>Confirm</source>
        <translation>Bevestigen</translation>
    </message>
    <message>
        <location filename="../../fileoperation.cpp" line="271"/>
        <source>Do you want to delete the selected files?</source>
        <translation>Wilt u de gekozen bestanden verwijderen?</translation>
    </message>
    <message>
        <location filename="../../fileoperation.cpp" line="288"/>
        <source>Do you want to move the selected files to trash can?</source>
        <translation>Wilt u de gekozen bestanden verplaatsen naar de prullenbak?</translation>
    </message>
</context>
<context>
    <name>Fm::FileOperationDialog</name>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="41"/>
        <source>Move files</source>
        <translation>Bestanden verplaatsen</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="42"/>
        <source>Moving the following files to destination folder:</source>
        <translation>Verplaats de volgende bestanden naar de bestemmingsmap:</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="45"/>
        <source>Copy Files</source>
        <translation>Bestanden kopiëren</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="46"/>
        <source>Copying the following files to destination folder:</source>
        <translation>Kopieer de volgende bestanden naar de bestemmingsmap:</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="49"/>
        <source>Trash Files</source>
        <translation>Bestanden naar de prullenbak verplaatsen</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="50"/>
        <source>Moving the following files to trash can:</source>
        <translation>Verplaats de volgende bestanden naar de prullenbak:</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="53"/>
        <source>Delete Files</source>
        <translation>Bestanden wissen</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="54"/>
        <source>Deleting the following files:</source>
        <translation>Wis de volgende bestanden:</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="59"/>
        <source>Create Symlinks</source>
        <translation>Symbolische koppelingen maken</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="60"/>
        <source>Creating symlinks for the following files:</source>
        <translation>Symbolische maken voor de volgende bestanden:</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="63"/>
        <source>Change Attributes</source>
        <translation>Eigenschappen veranderen</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="64"/>
        <source>Changing attributes of the following files:</source>
        <translation>Eigenschappen van de volgende bestanden veranderen:</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="69"/>
        <source>Restore Trashed Files</source>
        <translation>Bestanden terugzetten vanuit de prullenbak</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="70"/>
        <source>Restoring the following files from trash can:</source>
        <translation>De volgende bestanden terugzetten vanuit de prullenbak:</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="134"/>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
</context>
<context>
    <name>Fm::FilePropsDialog</name>
    <message>
        <location filename="../../filepropsdialog.cpp" line="156"/>
        <source>View folder content</source>
        <translation>Toon mapinhoud</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="157"/>
        <source>View and modify folder content</source>
        <translation>Mapinhoud tonen en wijzigen</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="161"/>
        <source>Read</source>
        <translation>Lezen</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="162"/>
        <source>Read and write</source>
        <translation>Lezen en schrijven</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="164"/>
        <source>Forbidden</source>
        <translation>Verboden</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="281"/>
        <source>Files of different types</source>
        <translation>Bestanden van verschillende soorten</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="304"/>
        <source>Multiple Files</source>
        <translation>Meerdere bestanden</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="380"/>
        <source>Select an icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="382"/>
        <source>Images (*.png *.xpm *.svg *.svgz )</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="478"/>
        <source>Apply changes</source>
        <translation>Veranderingen toepassen</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="479"/>
        <source>Do you want to recursively apply these changes to all files and sub-folders?</source>
        <translation>Wilt u de veranderingen toepassen op alle bestanden en onderliggende submappen?</translation>
    </message>
</context>
<context>
    <name>Fm::FileSearchDialog</name>
    <message>
        <location filename="../../filesearchdialog.cpp" line="128"/>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <location filename="../../filesearchdialog.cpp" line="128"/>
        <source>You should add at least one directory to search.</source>
        <translation>U dient tenminste één te doorzoeken map toe te voegen.</translation>
    </message>
    <message>
        <location filename="../../filesearchdialog.cpp" line="135"/>
        <source>Select a folder</source>
        <translation>Kies een map</translation>
    </message>
</context>
<context>
    <name>Fm::FolderMenu</name>
    <message>
        <location filename="../../foldermenu.cpp" line="41"/>
        <source>Create &amp;New</source>
        <translation>&amp;Nieuw maken</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="48"/>
        <source>&amp;Paste</source>
        <translation>&amp;Plakken</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="54"/>
        <source>Select &amp;All</source>
        <translation>&amp;Alle kiezen</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="58"/>
        <source>Invert Selection</source>
        <translation>Keuze omdraaien</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="64"/>
        <source>Sorting</source>
        <translation>Rangschikking</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="69"/>
        <source>Show Hidden</source>
        <translation>Toon verborgen</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="94"/>
        <source>Folder Pr&amp;operties</source>
        <translation>Map&amp;eigenschappen</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation type="vanished">Map</translation>
    </message>
    <message>
        <source>Blank File</source>
        <translation type="vanished">Lege map</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="137"/>
        <source>Output</source>
        <translation>Uitvoer</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="160"/>
        <source>By File Name</source>
        <translation>Op bestandnaam</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="161"/>
        <source>By Modification Time</source>
        <translation>Op wijzigingstijdstip</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="162"/>
        <source>By File Size</source>
        <translation>Op bestandgrootte</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="163"/>
        <source>By File Type</source>
        <translation>Op bestandsoort</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="164"/>
        <source>By File Owner</source>
        <translation>Op bestandeigenaar</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="176"/>
        <source>Ascending</source>
        <translation>Oplopend</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="181"/>
        <source>Descending</source>
        <translation>Aflopend</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="198"/>
        <source>Folder First</source>
        <translation>Map eerst</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="208"/>
        <source>Case Sensitive</source>
        <translation>Hoofdlettergevoelig</translation>
    </message>
</context>
<context>
    <name>Fm::FolderModel</name>
    <message>
        <location filename="../../foldermodel.cpp" line="242"/>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <location filename="../../foldermodel.cpp" line="245"/>
        <source>Type</source>
        <translation>Soort</translation>
    </message>
    <message>
        <location filename="../../foldermodel.cpp" line="248"/>
        <source>Size</source>
        <translation>Grootte</translation>
    </message>
    <message>
        <location filename="../../foldermodel.cpp" line="251"/>
        <source>Modified</source>
        <translation>Gewijzigd</translation>
    </message>
    <message>
        <location filename="../../foldermodel.cpp" line="254"/>
        <source>Owner</source>
        <translation>Eigenaar</translation>
    </message>
</context>
<context>
    <name>Fm::FontButton</name>
    <message>
        <location filename="../../fontbutton.cpp" line="46"/>
        <source>Bold</source>
        <translation>Vet</translation>
    </message>
    <message>
        <location filename="../../fontbutton.cpp" line="50"/>
        <source>Italic</source>
        <translation>Schuin</translation>
    </message>
</context>
<context>
    <name>Fm::MountOperationPasswordDialog</name>
    <message>
        <location filename="../../mountoperationpassworddialog.cpp" line="40"/>
        <source>&amp;Connect</source>
        <translation>&amp;Verbinden</translation>
    </message>
</context>
<context>
    <name>Fm::PathBar</name>
    <message>
        <location filename="../../pathbar.cpp" line="126"/>
        <source>&amp;Edit Path</source>
        <translation>Pad &amp;bewerken</translation>
    </message>
    <message>
        <location filename="../../pathbar.cpp" line="129"/>
        <source>&amp;Copy Path</source>
        <translation>Pad &amp;kopiëren</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesModel</name>
    <message>
        <location filename="../../placesmodel.cpp" line="44"/>
        <source>Places</source>
        <translation>Locaties</translation>
    </message>
    <message>
        <location filename="../../placesmodel.cpp" line="52"/>
        <source>Desktop</source>
        <translation>Bureaublad</translation>
    </message>
    <message>
        <location filename="../../placesmodel.cpp" line="231"/>
        <source>Trash</source>
        <translation>Prullenbak</translation>
    </message>
    <message>
        <location filename="../../placesmodel.cpp" line="60"/>
        <source>Computer</source>
        <translation>Computer</translation>
    </message>
    <message>
        <location filename="../../placesmodel.cpp" line="72"/>
        <source>Applications</source>
        <translation>Toepassingen</translation>
    </message>
    <message>
        <location filename="../../placesmodel.cpp" line="81"/>
        <source>Network</source>
        <translation>Netwerk</translation>
    </message>
    <message>
        <location filename="../../placesmodel.cpp" line="88"/>
        <source>Devices</source>
        <translation>Apparaten</translation>
    </message>
    <message>
        <location filename="../../placesmodel.cpp" line="142"/>
        <source>Bookmarks</source>
        <translation>Bladwijzers</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesView</name>
    <message>
        <location filename="../../placesview.cpp" line="370"/>
        <source>Empty Trash</source>
        <translation>Prullenbak ledigen</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="vanished">Hernoemen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">Wissen</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="356"/>
        <source>Open in New Tab</source>
        <translation>Open in nieuw tabblad</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="359"/>
        <source>Open in New Window</source>
        <translation>Open in nieuw venster</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="379"/>
        <source>Move Bookmark Up</source>
        <translation>Bladwijzer omhoog verplaatsen</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="384"/>
        <source>Move Bookmark Down</source>
        <translation>Bladwijzer naar beneden verplaatsen</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="388"/>
        <source>Rename Bookmark</source>
        <translation>Bladwijzer hernoemen</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="391"/>
        <source>Remove Bookmark</source>
        <translation>Bladwijzer verwijderen</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="400"/>
        <location filename="../../placesview.cpp" line="417"/>
        <source>Unmount</source>
        <translation>Ontkoppelen</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="404"/>
        <source>Mount</source>
        <translation>Aankoppelen</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="410"/>
        <source>Eject</source>
        <translation>Uitwerpen</translation>
    </message>
</context>
<context>
    <name>Fm::RenameDialog</name>
    <message>
        <location filename="../../renamedialog.cpp" line="50"/>
        <location filename="../../renamedialog.cpp" line="69"/>
        <source>Type: %1
Size: %2
Modified: %3</source>
        <translation>Soort: %1
Omvang: %2
Gewijzigd: %3</translation>
    </message>
    <message>
        <location filename="../../renamedialog.cpp" line="56"/>
        <location filename="../../renamedialog.cpp" line="75"/>
        <source>Type: %1
Modified: %2</source>
        <translation>Soort: %1
Veranderd: %2</translation>
    </message>
    <message>
        <location filename="../../renamedialog.cpp" line="89"/>
        <source>&amp;Overwrite</source>
        <translation>Over&amp;schrijven</translation>
    </message>
    <message>
        <location filename="../../renamedialog.cpp" line="91"/>
        <source>&amp;Rename</source>
        <translation>&amp;Hernoemen</translation>
    </message>
</context>
<context>
    <name>Fm::SidePane</name>
    <message>
        <location filename="../../sidepane.cpp" line="46"/>
        <source>Places</source>
        <translation>Locaties</translation>
    </message>
    <message>
        <location filename="../../sidepane.cpp" line="47"/>
        <source>Directory Tree</source>
        <translation>Boomstructuur van de mappen</translation>
    </message>
    <message>
        <source>Shows list of common places, devices, and bookmarks in sidebar</source>
        <translation type="vanished">Toont een lijst van gebruikelijke locaties, apparaten en bladwijzers in de zijbalk</translation>
    </message>
    <message>
        <source>Shows tree of directories in sidebar</source>
        <translation type="vanished">Toont een boomstructuur van de mappen in de zijbalk</translation>
    </message>
</context>
<context>
    <name>MountOperationPasswordDialog</name>
    <message>
        <location filename="../../mount-operation-password.ui" line="20"/>
        <source>Mount</source>
        <translation>Aankoppelen</translation>
    </message>
    <message>
        <location filename="../../mount-operation-password.ui" line="48"/>
        <source>Connect &amp;anonymously</source>
        <translation>&amp;Anoniem verbinden</translation>
    </message>
    <message>
        <location filename="../../mount-operation-password.ui" line="58"/>
        <source>Connect as u&amp;ser:</source>
        <translation>Verbinden als &amp;gebruiker:</translation>
    </message>
    <message>
        <location filename="../../mount-operation-password.ui" line="79"/>
        <source>&amp;Username:</source>
        <translation>Gebruikers&amp;naam:</translation>
    </message>
    <message>
        <location filename="../../mount-operation-password.ui" line="102"/>
        <source>&amp;Password:</source>
        <translation>&amp;Wachtwoord:</translation>
    </message>
    <message>
        <location filename="../../mount-operation-password.ui" line="112"/>
        <source>&amp;Domain:</source>
        <translation>&amp;Domein:</translation>
    </message>
    <message>
        <location filename="../../mount-operation-password.ui" line="127"/>
        <source>Forget password &amp;immediately</source>
        <translation>Wachtwoord &amp;direct vergeten</translation>
    </message>
    <message>
        <location filename="../../mount-operation-password.ui" line="137"/>
        <source>Remember password until you &amp;logout</source>
        <translation>Onthoud wachtwoord totdat u zich af&amp;meldt</translation>
    </message>
    <message>
        <location filename="../../mount-operation-password.ui" line="147"/>
        <source>Remember &amp;forever</source>
        <translation>Wachtwoord &amp;voor altijd onthouden</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../utilities.cpp" line="143"/>
        <location filename="../../utilities.cpp" line="232"/>
        <location filename="../../mountoperation.cpp" line="186"/>
        <location filename="../../filepropsdialog.cpp" line="503"/>
        <location filename="../../filelauncher.cpp" line="139"/>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="149"/>
        <source>Rename File</source>
        <translation>Bestand hernoemen</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="150"/>
        <source>Please enter a new name:</source>
        <translation>Voer a.u.b. een nieuwe naam in:</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="174"/>
        <source>Create Folder</source>
        <translation>Map maken</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="179"/>
        <source>Please enter a new file name:</source>
        <translation>Voer a.u.b. een nieuwe bestandnaam in:</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="180"/>
        <source>New text file</source>
        <translation>Nieuw tekstbestand</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="184"/>
        <source>Please enter a new folder name:</source>
        <translation>Voer a.u.b. een nieuwe mapnaam in:</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="185"/>
        <source>New folder</source>
        <translation>Nieuwe map</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="190"/>
        <source>Enter a name for the new %1:</source>
        <translation>Voer a.u.b. een naam in voor de/het nieuwe %1:</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="175"/>
        <source>Create File</source>
        <translation>Bestand maken</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="520"/>
        <source>Custom Icon Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <location filename="../../rename-dialog.ui" line="14"/>
        <source>Confirm to replace files</source>
        <translation>Vervangen van bestanden bevestigen</translation>
    </message>
    <message>
        <location filename="../../rename-dialog.ui" line="35"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;There is already a file with the same name in this location.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Do you want to replace the existing file?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Er is al een bestand met dezelfde naam op deze plek.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Wilt u het bestaande bestand vervangen?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../rename-dialog.ui" line="56"/>
        <source>dest</source>
        <translation>doel</translation>
    </message>
    <message>
        <location filename="../../rename-dialog.ui" line="63"/>
        <source>with the following file?</source>
        <translation>met het volgende bestand?</translation>
    </message>
    <message>
        <location filename="../../rename-dialog.ui" line="76"/>
        <source>src file info</source>
        <translation>Info over het bronbestand</translation>
    </message>
    <message>
        <location filename="../../rename-dialog.ui" line="89"/>
        <source>dest file info</source>
        <translation>Info over het doelbestand</translation>
    </message>
    <message>
        <location filename="../../rename-dialog.ui" line="102"/>
        <source>src</source>
        <translation>bron</translation>
    </message>
    <message>
        <location filename="../../rename-dialog.ui" line="122"/>
        <source>&amp;File name:</source>
        <translation>&amp;Bestandnaam:</translation>
    </message>
    <message>
        <location filename="../../rename-dialog.ui" line="137"/>
        <source>Apply this option to all existing files</source>
        <translation>Pas deze optie toe op alle bestaande bestanden</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../../filesearch.ui" line="14"/>
        <source>Search Files</source>
        <translation>Bestanden zoeken</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="29"/>
        <source>Name/Location</source>
        <translation>Naam/locatie</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="35"/>
        <source>File Name Patterns:</source>
        <translation>Patronen voor bestandnaam:</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="41"/>
        <source>*</source>
        <translation>*</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="48"/>
        <source>Case insensitive</source>
        <translation>Hoofdletterongevoelig</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="55"/>
        <source>Use regular expression</source>
        <translation>Gebruik reguliere uitdrukking</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="65"/>
        <source>Places to Search:</source>
        <translation>Te doorzoeken locaties:</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="78"/>
        <source>&amp;Add</source>
        <translation>&amp;Toevoegen</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="90"/>
        <source>&amp;Remove</source>
        <translation>&amp;Verwijderen</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="119"/>
        <source>Search in sub directories</source>
        <translation>Zoek in submappen</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="126"/>
        <source>Search for hidden files</source>
        <translation>Zoek naar verborgen bestanden</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="137"/>
        <source>File Type</source>
        <translation>Bestandsoort</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="143"/>
        <source>Only search for files of following types:</source>
        <translation>Zoek alleen naar bestanden van de volgende soorten:</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="149"/>
        <source>Text files</source>
        <translation>Tekstbestanden</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="156"/>
        <source>Image files</source>
        <translation>Afbeeldingbestanden</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="163"/>
        <source>Audio files</source>
        <translation>Geluidbestanden</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="170"/>
        <source>Video files</source>
        <translation>Videobestanden</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="177"/>
        <source>Documents</source>
        <translation>Documenten</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="184"/>
        <source>Folders</source>
        <translation>Mappen</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="208"/>
        <source>Content</source>
        <translation>Inhoud</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="214"/>
        <source>File contains:</source>
        <translation>Bestand bevat:</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="223"/>
        <source>Case insensiti&amp;ve</source>
        <translation>Hoofdletteronge&amp;voelig</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="230"/>
        <source>&amp;Use regular expression</source>
        <translation>Gebruik gewone uitdrukkingen</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="254"/>
        <source>Properties</source>
        <translation>Eigenschappen</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="260"/>
        <source>File Size:</source>
        <translation>Bestandgrootte:</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="289"/>
        <source>Larger than:</source>
        <translation>Groter dan:</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="303"/>
        <location filename="../../filesearch.ui" line="333"/>
        <source>Bytes</source>
        <translation>Bytes</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="308"/>
        <location filename="../../filesearch.ui" line="338"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="313"/>
        <location filename="../../filesearch.ui" line="343"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="318"/>
        <location filename="../../filesearch.ui" line="348"/>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="268"/>
        <source>Smaller than:</source>
        <translation>Kleiner dan:</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="364"/>
        <source>Last Modified Time:</source>
        <translation>Laatste wijzigingstijdstip:</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="372"/>
        <source>Earlier than:</source>
        <translation>Vroeger dan:</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="379"/>
        <source>Later than:</source>
        <translation>Later dan:</translation>
    </message>
</context>
</TS>
